<?php

if ( ! class_exists( 'Geeks_Acf_Field_Query_Control_Group' ) ) :
	/**
	 * Query Control ACF Field class
	 */
	class Geeks_Acf_Field_Query_Control_Group extends Geeks_Acf_Field_Group {

		/*
		*  __construct
		*
		*  This function will setup the field type data
		*
		*  @type    function
		*  @date    5/03/2014
		*  @since   5.0.0
		*
		*  @param   n/a
		*  @return  n/a
		*/
		function initialize() {

			// vars
			$this->name      = 'query_control_option';
			$this->label     = esc_html__( 'Query Control Options', 'geeks' );
			$this->category  = 'layout';
			$this->defaults  = array(
				'sub_fields' => array(),
				'layout'     => 'block',
				'post_types' => array( 'post' ),
			);
			$this->have_rows = 'single';

			// field filters
			$this->add_field_filter( 'acf/prepare_field_for_export', array( $this, 'prepare_field_for_export' ) );
			$this->add_field_filter( 'acf/prepare_field_for_import', array( $this, 'prepare_field_for_import' ) );
			add_filter( 'acf/load_field/type=query_control_option', array( $this, 'render_subfields' ) );
		}

		/*
		*  render_field()
		*
		*  Create the HTML interface for your field
		*
		*  @param   $field - an array holding all the field's data
		*
		*  @type    action
		*  @since   3.6
		*  @date    23/01/13
		*/
		function render_field( $field ) {

			// bail early if no sub fields
			if ( empty( $field['sub_fields'] ) ) {
				return;
			}

			$post_types = array();

			// load values
			foreach ( $field['sub_fields'] as &$sub_field ) {

				// add value
				if ( isset( $field['value'][ $sub_field['key'] ] ) ) {

					// this is a normal value
					$sub_field['value'] = $field['value'][ $sub_field['key'] ];

				} elseif ( isset( $sub_field['default_value'] ) ) {

					// no value, but this sub field has a default value
					$sub_field['value'] = $sub_field['default_value'];

				}

				// update prefix to allow for nested values
				$sub_field['prefix'] = $field['name'];

				// restore required
				if ( $field['required'] ) {
					$sub_field['required'] = 0;
				}

				if ( 'post_type' === $sub_field['name'] ) {
					$post_types[] = $field['value'][ $sub_field['key'] ];
				}

				if ( 'include_terms' === $sub_field['name'] ) {
					$taxonomies           = geeks_acf_get_taxonomies_for_post_types( $post_types );
					$terms                = geeks_acf_get_terms_for_taxonomies( $taxonomies );
					$sub_field['choices'] = $terms;
				}

				if ( 'include_authors' === $sub_field['name'] ) {
					$sub_field['choices'] = geeks_acf_get_author_users();
				}
			}

			// render
			if ( $field['layout'] == 'table' ) {
				$this->render_field_table( $field );
			} else {
				$this->render_field_block( $field );
			}
		}

		/*
		*  render_field_settings()
		*
		*  Create extra options for your field. This is rendered when editing a field.
		*  The value of $field['name'] can be used (like bellow) to save extra data to the $field
		*
		*  @type    action
		*  @since   3.6
		*  @date    23/01/13
		*
		*  @param   $field  - an array holding all the field's data
		*/
		function render_field_settings( $field ) {

			// layout
			parent::render_field_settings( $field );

			acf_render_field_setting(
				$field,
				array(
					'label'        => esc_html__( 'Post Types', 'geeks' ),
					'instructions' => esc_html__( 'Choose the post types you want to query', 'geeks' ),
					'type'         => 'select',
					'name'         => 'post_types',
					'multiple'     => true,
					'ui'           => true,
					'choices'      => geeks_acf_get_public_post_types(),
				)
			);
		}

		/*
		*  render_subfields()
		*
		*  Create the HTML interface for your sub field
		*
		*  @param   $field - an array holding all the sub field's data
		*
		*  @type    action
		*  @since   3.6
		*  @date    23/01/13
		*/
		function render_subfields( $field ) {

			$post_types = $field['post_types'];

			if ( is_array( $post_types ) ) {
				$post_types[] = 'by_id';
			} else {
				$post_types = array( 'by_id' );
			}

			$post_type_options = array();

			foreach ( $post_types as $post_type ) {
				if ( 'by_id' === $post_type ) {
					$post_type_options[ $post_type ] = esc_html__( 'Manual Selection', 'geeks' );
				} else {
					$post_type_object                = get_post_type_object( $post_type );
					$post_type_options[ $post_type ] = $post_type_object->label;
				}
			}

			$terms           = array();
			$authors_choises = array();

			$choises_field_options = array(
				'post_type'       => array(
					'label'             => esc_html__( 'Source', 'geeks' ),
					'default'           => $post_types[0] ? $post_types[0] : 'post',
					'choises'           => $post_type_options,
					'multiple'          => 0,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'orderby'         => array(
					'label'             => esc_html__( 'Order By', 'geeks' ),
					'default'           => 'post_date',
					'choises'           => array(
						'post_date'  => esc_html__( 'Date', 'geeks' ),
						'post_title' => esc_html__( 'Title', 'geeks' ),
						'menu_order' => esc_html__( 'Menu Order', 'geeks' ),
						'rand'       => esc_html__( 'Random', 'geeks' ),
					),
					'multiple'          => 0,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'order'           => array(
					'label'             => esc_html__( 'Order', 'geeks' ),
					'default'           => 'desc',
					'choises'           => array(
						'asc'  => esc_html__( 'ASC', 'geeks' ),
						'desc' => esc_html__( 'DESC', 'geeks' ),
					),
					'multiple'          => 0,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'include'         => array(
					'label'             => esc_html__( 'Include By', 'geeks' ),
					'choises'           => array(
						'terms'   => esc_html__( 'Term', 'geeks' ),
						'authors' => esc_html__( 'Author', 'geeks' ),
					),
					'default'           => '',
					'multiple'          => 1,
					'conditional_logic' => array(
						array(
							'field'    => 'field_post_type',
							'operator' => '!=',
							'value'    => 'by_id',
						),
					),
					'instructions'      => '',
				),
				'include_terms'   => array(
					'label'             => esc_html__( 'Term', 'geeks' ),
					'choises'           => $terms,
					'multiple'          => 1,
					'default'           => '',
					'conditional_logic' => array(
						array(
							'field'    => 'field_include',
							'operator' => '==',
							'value'    => 'terms',
						),
						array(
							'field'    => 'field_post_type',
							'operator' => '!=',
							'value'    => 'by_id',
						),
					),
					'instructions'      => '',
				),
				'include_authors' => array(
					'label'             => esc_html__( 'Author', 'geeks' ),
					'choises'           => $authors_choises,
					'multiple'          => 1,
					'default'           => '',
					'conditional_logic' => array(
						array(
							'field'    => 'field_include',
							'operator' => '==',
							'value'    => 'authors',
						),
						array(
							'field'    => 'field_post_type',
							'operator' => '!=',
							'value'    => 'by_id',
						),
					),
					'instructions'      => '',
				),
			);

			foreach ( $choises_field_options as $key => $choises_field_option ) {

				$field['sub_fields'][] = array(
					'ID'                => uniqid(),
					'key'               => 'field_' . $key,
					'label'             => $choises_field_option['label'],
					'name'              => $key,
					'_name'             => $key,
					'type'              => 'select',
					'choices'           => $choises_field_option['choises'],
					'multiple'          => $choises_field_option['multiple'],
					'return_format'     => 'value',
					'ui'                => 1,
					'required'          => 0,
					'conditional_logic' => $choises_field_option['conditional_logic'],
					'default_value'     => $choises_field_option['default'],
					'wrapper'           => array(
						'width' => '',
						'class' => '',
						'id'    => '',
					),
					'instructions'      => $choises_field_option['instructions'],
				);
			}

			$field['sub_fields'][] = array(
				'ID'                => uniqid(),
				'label'             => esc_html__( 'Post Ids', 'geeks' ),
				'key'               => 'field_posts_ids',
				'name'              => 'posts_ids',
				'_name'             => 'posts_ids',
				'type'              => 'text',
				'multiple'          => 1,
				'required'          => 0,
				'conditional_logic' => array(
					array(
						'field'    => 'field_post_type',
						'operator' => '==',
						'value'    => 'by_id',
					),
				),
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'instructions'      => 'Enter Post Ids seperated by commo',
			);

			$field['sub_fields'][] = array(
				'ID'                => uniqid(),
				'label'             => esc_html__( 'Posts Per Page', 'geeks' ),
				'key'               => 'field_posts_per_page',
				'name'              => 'posts_per_page',
				'_name'             => 'posts_per_page',
				'type'              => 'number',
				'min'               => 1,
				'required'          => 0,
				'default_value'     => 4,
				'conditional_logic' => 0,
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'instructions'      => '',
			);

			return $field;
		}
	}

	// initialize
	acf_register_field_type( 'Geeks_Acf_Field_Query_Control_Group' );
endif;
