<?php
/**
 * Template functions used in Footer
 */

/**
 * Display the footer.
 *
 * @param string $args Additional arguments passed to the footer template.
 */
function geeks_display_footer( $args ) {
	if ( ! apply_filters( 'geeks_footer_disabled', false ) ) {
		$default = geeks_footer_variant();
		$version = isset( $args['version'] ) ? $args['version'] : $default;
		$version = apply_filters( 'geeks_footer_version', $version );
		geeks_get_template( 'footer/footer-' . $version . '.php' );
	}
}

/**
 * Includes the footer template for the theme
 *
 * @param string $version The name of the specialised footer.
 * @return void
 */
function geeks_get_footer( $version = null ) {
	$version = (string) $version;
	if ( '' !== $version ) {
		get_footer( null, array( 'version' => $version ) );
	} else {
		get_footer();
	}
}

/**
 * Checks if a page has custom footer or not
 *
 * @param array $options Page meta options.
 */
function geeks_has_custom_footer( $options ) {
	$has_custom_footer = false;

	if ( isset( $options['footer'] ) && isset( $options['footer']['geeks_enable_custom_footer'] ) && 'yes' === $options['footer']['geeks_enable_custom_footer'] ) {
		$has_custom_footer = true;
	}

	return $has_custom_footer;
}


if ( ! function_exists( 'geeks_footer_variant' ) ) {
	/**
	 * Display the footer variant.
	 *
	 * @since  1.0.0
	 * @return string
	 */
	function geeks_footer_variant() {

		$custom_footer = geeks_get_field( 'geeks_enable_custom_footer' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_footer( $gk_page_options ) ) {
			$variant = isset( $gk_page_options['footer']['footer_variant'] ) ? $gk_page_options['footer']['footer_variant'] : 'v1';
		} elseif ( $custom_footer ) {
			$variant = geeks_get_field( 'geeks_footer_variant' );
		} else {
			$variant = get_theme_mod( 'footer_variant', 'v1' );
		}

		return sanitize_key( apply_filters( 'geeks_footer_variant', $variant ) );
	}
}

if ( ! function_exists( 'geeks_footer_widgets' ) ) {
	/**
	 * Display the footer widget regions.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function geeks_footer_widgets() {

		$custom_footer = geeks_get_field( 'geeks_enable_custom_footer' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_footer( $gk_page_options ) ) {
			$enable_widgets = isset( $gk_page_options['footer']['geeks_enable_footer_widgets'] ) ? $gk_page_options['footer']['geeks_enable_footer_widgets'] : '';
		} elseif ( $custom_footer ) {
			$enable_widgets = geeks_get_field( 'geeks_enable_footer_widgets' );
		} else {
			$enable_widgets = get_theme_mod( 'enable_footer_widgets', false );
		}

		if ( ! $enable_widgets ) {
			return;
		}

		$rows    = intval( apply_filters( 'geeks_footer_widget_rows', 1 ) );
		$regions = intval( apply_filters( 'geeks_footer_widget_columns', 4 ) );

		if ( geeks_is_gke_activated() ) {
			$col_classes = [
				'col-lg-4 col-md-6 col-12',
				'offset-lg-1 col-lg-2 col-md-3 col-6',
				'col-lg-2 col-md-3 col-6',
				'col-lg-3 col-md-12',
			];
		} else {
			$col_classes = [
				'col-lg-4 col-md-6 col-12',
				'offset-xl-1 col-lg-2 col-md-6 col-12',
				'col-lg-2 col-md-6 col-12',
				'col-lg-3 col-md-6 col-12',
			];
		}

		for ( $row = 1; $row <= $rows; $row++ ) :

			// Defines the number of active columns in this footer row.
			for ( $region = $regions; 0 < $region; $region-- ) {
				if ( is_active_sidebar( 'footer-' . esc_attr( $region + $regions * ( $row - 1 ) ) ) ) {
					$columns = $region;
					break;
				}
			}

			if ( isset( $columns ) ) :
				?>
				<div class="footer-widgets row pt-lg-10 pt-5 mb-6">
				<?php

				for ( $column = 1; $column <= $columns; $column++ ) :
					$footer_n = $column + $regions * ( $row - 1 );

					if ( is_active_sidebar( 'footer-' . esc_attr( $footer_n ) ) ) :
						$footer_widget_class = 'footer-widget-' . $column . ' mb-4 mb-0-last-child';
						if ( isset( $col_classes[ $column - 1 ] ) ) {
							$footer_widget_class .= ' ' . $col_classes[ $column - 1 ];
						}
						?>
					<div class="<?php echo esc_attr( $footer_widget_class ); ?>">
						<?php dynamic_sidebar( 'footer-' . esc_attr( $footer_n ) ); ?>
					</div>
						<?php
					endif;

				endfor;

				?>
			</div><!-- .footer-widgets.row-<?php echo esc_attr( $row ); ?> -->
				<?php
				unset( $columns );
			endif;
		endfor;
	}
}

if ( ! function_exists( 'geeks_get_copyright_text' ) ) {
	/**
	 * Get the theme copyright text
	 *
	 * @return string
	 */
	function geeks_get_copyright_text() {

		$custom_footer   = geeks_get_field( 'geeks_enable_custom_footer' );
		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_footer( $gk_page_options ) ) {
			$content = isset( $gk_page_options['footer']['geeks_footer_copyright'] ) ? $gk_page_options['footer']['geeks_footer_copyright'] : '';
		} elseif ( $custom_footer ) {
			$content = geeks_get_field( 'geeks_footer_copyright' );
		} else {
			$content = get_theme_mod( 'geeks_copyright', sprintf( '&copy; %s %s. %s', gmdate( 'Y' ), get_bloginfo( 'name' ), esc_html__( 'All Rights Reserved', 'geeks' ) ) );
		}

		return (string) apply_filters( 'geeks_footer_copyright', $content );
	}
}

if ( ! function_exists( 'geeks_credit' ) ) {
	/**
	 * Display the theme credit
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function geeks_credit() {
		$copyright = geeks_get_copyright_text();
		?>
		<div class="site-info row align-items-center g-0 border-top py-2">
			<div class="col-lg-4 col-md-5 col-12 text-center text-md-start">
				<span class="geeks-copyright">
					<?php echo wp_kses_post( $copyright ); ?>
				</span>
			</div>

			<?php if ( has_nav_menu( 'footer' ) ) : ?>
			<div class="col-12 col-md-7 col-lg-8 d-md-flex justify-content-end mt-2 mt-md-0">
				<?php geeks_footer_menu(); ?>
			</div>
			<?php endif; ?>
		</div><!-- .site-info -->
		<?php
	}
}

if ( ! function_exists( 'geeks_footer_background' ) ) {
	/**
	 * Displays footer background option
	 */
	function geeks_footer_background() {

		$custom_footer = geeks_get_field( 'geeks_enable_custom_footer' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_footer( $gk_page_options ) ) {
			$footer_bg = isset( $gk_page_options['footer']['geeks_enable_footer_white_background'] ) ? $gk_page_options['footer']['geeks_enable_footer_white_background'] : '';
		} elseif ( $custom_footer ) {
			$footer_bg = geeks_get_field( 'geeks_enable_footer_white_background' );
		} else {
			$footer_bg = get_theme_mod( 'enable_footer_white_background', false );
		}

		return apply_filters( 'enable_footer_white_background', filter_var( $footer_bg, FILTER_VALIDATE_BOOLEAN ) );
	}
}


if ( ! function_exists( 'geeks_social_media_links' ) ) {
	/**
	 * Displays social media links
	 */
	function geeks_social_media_links() {
		$footer_variant = geeks_footer_variant();
		$menu_classes = '';
		$anchor_classes = '';

		if ( 'v2' === $footer_variant ) {
			$menu_classes = 'justify-content-center mb-0';
			$anchor_classes = ['me-4', 'lh-1', 'text-muted', 'text-primary-hover', 'fs-3', 'pe-1' ];
		} elseif( 'v1' === $footer_variant ) {
			$menu_classes = 'fs-4 mt-4 flex-row';
			$anchor_classes = ['text-muted', 'me-2', 'p-0', 'fs-4', 'lh-1','pe-1'];
		}

		wp_nav_menu(
			array(
				'theme_location' => 'social',
				'container'      => false,
				'menu_class'     => 'social-menu list-unstyled d-flex align-items-center ' . $menu_classes. '',
				'anchor_class'   => $anchor_classes,
				'walker'         => new WP_Bootstrap_Navwalker(),
			)
		);
	}
}

if ( ! function_exists( 'geeks_footer_speciality_social_media_links' ) ) {
	/**
	 * Displays social media links
	 */
	function geeks_footer_speciality_social_media_links() {
		wp_nav_menu(
			array(
				'theme_location' => 'social',
				'container'      => false,
				'menu_class'     => 'social-menu nav me-n3',
				'anchor_class'   => [ 'text-muted', 'text-primary-hover', 'me-3' ],
				'walker'         => new WP_Bootstrap_Navwalker(),
			)
		);
	}
}

if ( ! function_exists( 'geeks_footer_menu' ) ) {
	/**
	 * Displays footer menu
	 */
	function geeks_footer_menu() {
		$footer_variant = geeks_footer_variant();
		if ( 'v2' === $footer_variant ) {
			$menu_classes = 'nav nav-footer justify-content-center';
		} else {
			$menu_classes = 'nav nav-footer justify-content-center justify-content-lg-end';
		}

		wp_nav_menu(
			[
				'container'      => false,
				'theme_location' => 'footer',
				'menu_class'     => $menu_classes,
				'depth'          => 1,
				'link_before'    => '<span class="nav-link">',
				'link_after'     => '</span>',
			]
		);
	}
}

if ( ! function_exists( 'geeks_footer_menu_wrap' ) ) {
	/**
	 * Displays footer v2 menu wrap
	 */
	function geeks_footer_menu_wrap() {
		if ( has_nav_menu( 'footer' ) ) :
			?>
			<div class="col-12 col-md-12 col-xl-8 px-0">
			<?php
				geeks_footer_menu();
			?>
			</div>
			<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_footer_social_media_links_wrap' ) ) {
	/**
	 * Displays footer v2 social media wrap
	 */
	function geeks_footer_social_media_links_wrap() {
		if ( has_nav_menu( 'social' ) ) :
			?>
			<div class="col-lg-8 col-md-12 col-12"><div class="my-6">
			<?php
				geeks_social_media_links();
			?>
			</div></div>
			<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_footer_copyright_wrap' ) ) {
	/**
	 * Displays footer v2 copyright wrap
	 */
	function geeks_footer_copyright_wrap() {
		$copyright  = geeks_get_copyright_text();
		$footer_css = 'col-lg-8 col-md-12 col-12';
		if ( ! has_nav_menu( 'social' ) ) {
			$footer_css .= ' mt-6';
		}

		?>
		<div class="<?php echo esc_attr( $footer_css ); ?>">
			<span class="geeks-copyright"><?php echo wp_kses_post( $copyright ); ?></span>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_footer_speciality_copyright_wrap' ) ) {
	/**
	 * Displays footer speciality copyright wrap
	 */
	function geeks_footer_speciality_copyright_wrap() {
		$copyright = geeks_get_copyright_text();
		?>
		<div class="col-md-6 col-12 text-center text-md-start">
			<span class="geeks-copyright mb-0"><?php echo wp_kses_post( $copyright ); ?></span>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_footer_speciality_social_media_links_wrap' ) ) {
	/**
	 * Displays footer speciality social media wrap
	 */
	function geeks_footer_speciality_social_media_links_wrap() {
		if ( has_nav_menu( 'social' ) ) :
			?>
			<div class="col-md-6 col-12 d-flex justify-content-center justify-content-md-end mt-1 mt-md-0">
			<?php
				geeks_footer_speciality_social_media_links();
			?>
			</div>
			<?php
		endif;
	}
}
