<?php
/**
 * Template functions used in Header
 */

/**
 * Display the header.
 *
 * @param string $args Additional arguments passed to the header template.
 */
function geeks_display_header( $args ) {
	if ( ! apply_filters( 'geeks_navbar_disabled', false ) ) {
		$default = geeks_get_default_header();
		$version = isset( $args['version'] ) ? $args['version'] : $default;
		$version = apply_filters( 'geeks_header_version', $version );
		geeks_get_template( 'header/header-' . $version . '.php' );
	}
}

/**
 * Get default header version.
 *
 * @return string
 */
function geeks_get_default_header() {
	$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

	$gk_page_options = array();

	if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
		$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
		$_gk_page_options = maybe_unserialize( $clean_meta_data );

		if ( is_array( $_gk_page_options ) ) {
			$gk_page_options = $_gk_page_options;
		}
	}

	if ( geeks_has_custom_header( $gk_page_options ) ) {
		$variant = isset( $gk_page_options['header']['header_variant'] ) ? $gk_page_options['header']['header_variant'] : 'v1';
	} elseif ( $custom_header ) {
		$variant = geeks_get_field( 'geeks_header_variant' );
	} else {
		$variant = get_theme_mod( 'header_variant', 'v1' );
	}

	return apply_filters( 'geeks_default_header', $variant );
}

/**
 * Includes the header template for the theme
 *
 * @param string $version The name of the specialised header.
 * @return void
 */
function geeks_get_header( $version = null ) {
	$version = (string) $version;
	if ( '' !== $version ) {
		get_header( null, array( 'version' => $version ) );
	} else {
		get_header();
	}
}

/**
 * Check if a page has custom header
 *
 * @param array $options Page meta options.
 */
function geeks_has_custom_header( $options ) {
	$has_custom_header = false;

	if ( isset( $options['header'] ) && isset( $options['header']['geeks_enable_custom_header'] ) && 'yes' === $options['header']['geeks_enable_custom_header'] ) {
		$has_custom_header = true;
	}

	return $has_custom_header;
}

if ( ! function_exists( 'geeks_site_title_or_logo' ) ) {
	/**
	 * Display the site title or logo
	 *
	 * @param bool   $echo Echo the string or return it.
	 * @param string $img_link_css the string or return it.
	 * @param string $txt_link_css the string or return it
	 * @return string
	 */
	function geeks_site_title_or_logo( $echo = true, $img_link_css = 'navbar-brand', $txt_link_css = 'site-title h2 me-3 fw-bold mb-0' ) {
		$inverse_logo_id = (int) get_theme_mod( 'logo_inverse' );

		if ( $inverse_logo_id && geeks_navbar_is_dark() ) {

			// If the logo alt attribute is empty, get the site title.
			$inverse_logo_alt = get_post_meta( $inverse_logo_id, '_wp_attachment_image_alt', true );

			if ( empty( $inverse_logo_alt ) ) {
				$inverse_logo_attr['alt'] = get_bloginfo( 'name', 'display' );
			}

			$html = sprintf(
				'<a href="%1$s" class="%3$s" rel="home">%2$s</a>',
				esc_url( home_url( '/' ) ),
				wp_get_attachment_image( $inverse_logo_id, 'full', false, $inverse_logo_attr ),
				$img_link_css
			);

		} elseif ( function_exists( 'the_custom_logo' ) && has_custom_logo() ) {
			$logo = get_custom_logo();
			$html = str_replace( '"custom-logo-link"', '"' . $img_link_css . '"', $logo );

		} else {
			$html = '<a href="' . esc_url( home_url( '/' ) ) . '" class="' . esc_attr( $txt_link_css ) . '" rel="home">' . esc_html( get_bloginfo( 'name' ) ) . '</a>';
		}

		if ( ! $echo ) {
			return $html;
		}

		echo apply_filters( 'geeks_site_title_or_logo_html', $html ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}
}

if ( ! function_exists( 'geeks_site_branding' ) ) {
	/**
	 * Site branding wrapper and display
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function geeks_site_branding() {
		geeks_site_title_or_logo( true );
	}
}

if ( ! function_exists( 'geeks_navbar_toggler' ) ) {
	/**
	 * Output Navbar Toggler
	 */
	function geeks_navbar_toggler() {
		?><button class="navbar-toggler collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#navbar-default" aria-controls="navbar-default" aria-expanded="false" aria-label="Toggle navigation">
			<span class="icon-bar top-bar mt-0"></span>
			<span class="icon-bar middle-bar"></span>
			<span class="icon-bar bottom-bar"></span>
	   </button>
		<?php
	}
}

if ( ! function_exists( 'geeks_navbar_collapse_start' ) ) {
	/**
	 * Output Navbar Collapse Start
	 */
	function geeks_navbar_collapse_start() {
		?>
		<div class="collapse navbar-collapse" id="navbar-default">
		<?php
	}
}

if ( ! function_exists( 'geeks_navbar_right_wrap_start' ) ) {
	/**
	 * Output Navbar Right Wrap Start
	 */
	function geeks_navbar_right_wrap_start() {
		?>
		<div class="mobile-view-links ms-auto d-flex align-item-center d-lg-none">
		<?php
	}
}


if ( ! function_exists( 'geeks_navbar_collapse_end' ) ) {
	/**
	 * Output Navbar Collapse End
	 */
	function geeks_navbar_collapse_end() {
		?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_navbar_nav_primary' ) ) {
	/**
	 * Output Navbar Menu
	 */
	function geeks_navbar_nav_primary() {
		if ( has_nav_menu( 'navbar' ) ) {
			wp_nav_menu(
				[
					'container'      => false,
					'theme_location' => 'navbar',
					'menu_class'     => 'navbar-nav',
					'fallback_cb'    => 'WP_Bootstrap_Navwalker::fallback',
					'walker'         => new WP_Bootstrap_Navwalker(),
				]
			);
		}
	}
}

if ( ! function_exists( 'geeks_navbar_is_search' ) ) {
	/**
	 * Enable Search
	 */
	function geeks_navbar_is_search() {

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$enable_search = isset( $gk_page_options['header']['geeks_enable_navbar_search'] ) ? $gk_page_options['header']['geeks_enable_navbar_search'] : '';
		} elseif ( $custom_header ) {
			$enable_search = geeks_get_field( 'geeks_enable_navbar_search' );
		} else {
			$enable_search = get_theme_mod( 'enable_search', true );
		}

		return apply_filters( 'geeks_enable_search', filter_var( $enable_search, FILTER_VALIDATE_BOOLEAN ) );
	}
}


if ( ! function_exists( 'geeks_navbar_search' ) ) {
	function geeks_navbar_search() {
		if ( geeks_navbar_is_search() ) :

			$post_type = 'post';
			$placeholder = esc_html__( 'Search …', 'geeks' );

			if ( geeks_is_tutor_activated() ) {
				$post_type = 'courses';
				$placeholder = esc_html__( 'Search Courses', 'geeks' );
			}

			?>
			<div class="navbar-search mt-3 mt-lg-0 ms-lg-3">
				<form role="search" method="get" class="search-form d-flex align-items-center" action="<?php echo esc_url( home_url( '/' ) ); ?>">
					<span class="position-absolute ps-3 search-icon"><i class="fe fe-search"></i></span>
					<input type="search" class="search-field form-control ps-6" placeholder="<?php echo esc_attr( $placeholder ); ?>" value="<?php echo esc_attr( get_search_query() ); ?>" name="s" title="<?php echo esc_attr__( 'Search for:', 'geeks' ) ?>">
					<input type="hidden" class="form-control" name="post_type" value="<?php echo esc_attr( $post_type ); ?>">
				</form>
			</div>
			<?php
		endif;
	}
}


if ( ! function_exists( 'geeks_navbar_is_user_profile_info' ) ) {
	/**
	 * Enable User Profile Info
	 */
	function geeks_navbar_is_user_profile_info() {

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$enable_user_profile = isset( $gk_page_options['header']['geeks_enable_user_profile'] ) ? $gk_page_options['header']['geeks_enable_user_profile'] : '';
		} elseif ( $custom_header ) {
			$enable_user_profile = geeks_get_field( 'geeks_enable_user_profile' );
		} else {
			$enable_user_profile = get_theme_mod( 'enable_user_profile', true );
		}

		return apply_filters( 'geeks_enable_user_profile', filter_var( $enable_user_profile, FILTER_VALIDATE_BOOLEAN ) );
	}
}

if ( ! function_exists( 'geeks_navbar_is_enable_cart' ) ) {
	/**
	 * Enable Cart
	 */
	function geeks_navbar_is_enable_cart() {

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$enable_cart = isset( $gk_page_options['header']['geeks_enable_cart'] ) ? $gk_page_options['header']['geeks_enable_cart'] : '';
		} elseif ( $custom_header ) {
			$enable_cart = geeks_get_field( 'geeks_enable_cart' );
		} else {
			$enable_cart = get_theme_mod( 'enable_cart', false );
		}

		return apply_filters( 'geeks_enable_cart', filter_var( $enable_cart, FILTER_VALIDATE_BOOLEAN ) );
	}
}

if ( ! function_exists( 'geeks_navbar_is_dark' ) ) {
	/**
	 * Enable Dark Navbar
	 */
	function geeks_navbar_is_dark() {

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$enable_dark_header = isset( $gk_page_options['header']['geeks_enable_dark_header'] ) ? $gk_page_options['header']['geeks_enable_dark_header'] : '';
		} elseif ( $custom_header ) {
			$enable_dark_header = geeks_get_field( 'geeks_enable_dark_header' );
		} else {
			$enable_dark_header = get_theme_mod( 'enable_dark_header', false );
		}

		return apply_filters( 'geeks_navbar_is_dark_header', filter_var( $enable_dark_header, FILTER_VALIDATE_BOOLEAN ) );
	}
}



if ( ! function_exists( 'geeks_navbar_is_sticky' ) ) {
	/**
	 * Check header sticky
	 *
	 * @return bool
	 */
	function geeks_navbar_is_sticky() {
		global $post;

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$sticky_header = isset( $gk_page_options['header']['geeks_enable_sticky'] ) && 'yes' === $gk_page_options['header']['geeks_enable_sticky'] ? true : false;

		} elseif ( $custom_header ) {
			$sticky_header = geeks_get_field( 'geeks_enable_sticky' );
		} else {
			$sticky_header = get_theme_mod( 'enable_sticky', false );
		}

		return apply_filters( 'geeks_enable_navbar_sticky', filter_var( $sticky_header, FILTER_VALIDATE_BOOLEAN ) );
	}
}


if ( ! function_exists( 'geeks_navbar_is_button' ) ) {
	/**
	 * Navbar Button
	 */
	function geeks_navbar_is_button() {

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$enable_button = isset( $gk_page_options['header']['geeks_enable_navbar_button'] ) ? $gk_page_options['header']['geeks_enable_navbar_button'] : '';
		} elseif ( $custom_header ) {
			$enable_button = geeks_get_field( 'geeks_enable_navbar_button' );
		} else {
			$enable_button = get_theme_mod( 'enable_action_button', false );
		}

		return apply_filters( 'geeks_navbar_is_buutton', filter_var( $enable_button, FILTER_VALIDATE_BOOLEAN ) );
	}
}

if ( ! function_exists( 'geeks_navbar_is_fullwidth' ) ) {
	/**
	 * Returns if the navbar of a page is fullwidth
	 */
	function geeks_navbar_is_fullwidth() {

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$enable_navbar_fullwidth = isset( $gk_page_options['header']['geeks_enable_navbar_full_width'] ) ? $gk_page_options['header']['geeks_enable_navbar_full_width'] : '';
		} elseif ( $custom_header ) {
			$enable_navbar_fullwidth = geeks_get_field( 'geeks_enable_navbar_full_width' );
		} else {
			$enable_navbar_fullwidth = get_theme_mod( 'header_is_full_width', true );
		}

		return apply_filters( 'geeks_navbar_is_fullwidth', filter_var( $enable_navbar_fullwidth, FILTER_VALIDATE_BOOLEAN ) );
	}
}

if ( ! function_exists( 'geeks_navbar_right' ) ) {
	function geeks_navbar_right() {
		if ( geeks_navbar_is_user_profile_info() ) :
			if ( is_user_logged_in() ) :
				$user   = wp_get_current_user();
				$avatar = get_avatar( $user->ID, 40, '', '', array( 'class' => 'rounded-circle' ) );

				if( geeks_navbar_is_enable_cart() ) {
					$profile_class = 'ms-5';
				} else {
					$profile_class = 'ms-auto';
				}

				?>
				<ul class="user-profile navbar-nav navbar-right-wrap d-none d-lg-block <?php echo esc_attr( $profile_class ); ?>">
					<li class="dropdown ms-2 d-inline-block">
						<a class="rounded-circle" href="#" role="button" id="dropdownUserProfile" data-bs-toggle="dropdown" data-bs-display="static" aria-expanded="false">
						   <div class="avatar avatar-md"><?php echo wp_kses_post( $avatar ); ?></div>
						</a>
						<div class="dropdown-menu dropdown-menu-end" aria-labelledby="dropdownUserProfile">
							<div class="dropdown-item">
								<div class="d-flex">
									<div class="avatar avatar-md"><?php echo wp_kses_post( $avatar ); ?></div>
									<div class="ms-3 lh-1">
										<h5 class="mb-1"><?php echo esc_html( $user->data->display_name ); ?></h5>
										<p class="mb-0 text-muted"><?php echo esc_html( $user->data->user_email ); ?></p>
									</div>
								</div>
							</div>
							<div class="dropdown-divider"></div>

							<?php if ( geeks_is_tutor_activated() ) : ?>
								<ul class="list-unstyled">
								
									<?php
									$geeks_dashboard_pages = apply_filters(
										'geeks_header_tutor_dashboard_menu_items',
										array(
											'settings' => array(
												'title' => esc_html__( 'Profile', 'geeks' ),
												'icon'  => 'fe fe-user',
											),
											'reviews'  => array(
												'title' => esc_html__( 'Reviews', 'geeks' ),
												'icon'  => 'fe fe-star',
											),
											'settings/withdraw-settings' => array(
												'title' => esc_html__( 'Settings', 'geeks' ),
												'icon'  => 'fe fe-settings',
											),

										)
									);

									$disable = ! get_tutor_option( 'enable_course_review' );

									if ( $disable && isset( $geeks_dashboard_pages['reviews'] ) ) {
										unset( $geeks_dashboard_pages['reviews'] );
									}

									foreach ( $geeks_dashboard_pages as $dashboard_key => $dashboard_page ) {
										$menu_title = $dashboard_page;
										$menu_link  = tutils()->get_tutor_dashboard_page_permalink( $dashboard_key );

										if ( is_array( $dashboard_page ) ) {
											$menu_title = tutils()->array_get( 'title', $dashboard_page );
											$menu_icon  = tutils()->array_get( 'icon', $dashboard_page );

											echo "<li><a class='dropdown-item' href='" . $menu_link . "'><i class='" . $menu_icon . "'></i> {$menu_title} </a> </li>";
										} else {
											echo "<li><a class='dropdown-item' href='" . $menu_link . "'>{$menu_title} </a> </li>";

										}
									}
									?>
									<li class="dropdown-divider"></li>
									<li>
										<a class="dropdown-item" href="<?php echo tutils()->tutor_dashboard_url( 'logout' ); ?>">
											<i class="fe fe-power me-2"></i><?php echo esc_html__( 'Sign Out', 'geeks' ); ?>
										</a>
									</li>
								</ul>

								<?php
							elseif ( geeks_is_woocommerce_activated() ) :
								geeks_wc_my_account_endpoint_dropdown();
							else :
								?>

								<ul class="list-unstyled">
									<li>
										<a class="dropdown-item" href="<?php echo wp_logout_url(); ?>">
											<i class="fe fe-power me-2"></i><?php echo esc_html__( 'Sign Out', 'geeks' ); ?>
										</a>
									</li>
								</ul>

							<?php endif; ?>
						</div>
					</li>
				</ul>
				<?php
			else :
				if ( geeks_is_tutor_activated() ) :
					$current_url   = tutils()->get_current_url();
					$register_page = tutor_utils()->student_register_url();
					$register_url  = add_query_arg( 'redirect_to', $current_url, $register_page );
					if( !is_user_logged_in() ) {
						$wrap_class = ' tutor-course-entry-box-login';
					} else {
						$wrap_class = '';
					}
					?>

					<div class="ms-auto mt-lg-0 user-account-link">
						<span class="d-inline-block<?php echo esc_attr( $wrap_class ); ?>">
							<a href="javascript:;" class="cart-required-login btn btn-white shadow-sm me-1"><?php echo esc_html__( ' Sign In', 'geeks' ); ?></a>
						</span>

						<?php if ( get_option( 'users_can_register', false ) ) { ?>
							<a href="<?php echo esc_url( $register_url ); ?>" class="d-none d-lg-inline-block btn btn-primary"><?php echo esc_html__( 'Sign Up', 'geeks' ); ?></a>
						<?php } ?>
					</div>
					<?php
					if ( ! is_user_logged_in() ) {
						tutor_load_template( 'global.login' );
					}
					?>
					<?php
				elseif ( geeks_is_woocommerce_activated() ) :
					$user_account_link = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
					?>
					<div class="ms-auto mt-lg-0 user-account-link">
						<a href="#wcAccountModal" class="btn btn-white shadow-sm me-1" data-bs-toggle="modal" data-view="#modal-signin-view"><?php echo esc_html__( ' Sign In', 'geeks' ); ?></a>

						<?php if ( get_option( 'woocommerce_enable_myaccount_registration' ) === 'yes' ) { ?>
							<a href="#wcAccountModal" data-bs-toggle="modal" data-view="#modal-signup-view" class="btn btn-primary d-none d-lg-inline-block"><?php echo esc_html__( 'Sign Up', 'geeks' ); ?></a>
						<?php } ?>
					</div>
					<?php
				endif;
			endif;
		endif;

	}
}

if ( ! function_exists( 'geeks_navbar_button' ) ) {
	function geeks_navbar_button() {
		if ( geeks_navbar_is_button() ) :

			$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

			$gk_page_options = array();

			if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
				$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
				$_gk_page_options = maybe_unserialize( $clean_meta_data );

				if ( is_array( $_gk_page_options ) ) {
					$gk_page_options = $_gk_page_options;
				}
			}

			if ( geeks_has_custom_header( $gk_page_options ) ) {
				$button_variant = isset( $gk_page_options['header']['geeks_navbar_button_variant'] ) ? $gk_page_options['header']['geeks_navbar_button_variant'] : '';
				$button_url     = isset( $gk_page_options['header']['geeks_navbar_button_link'] ) ? $gk_page_options['header']['geeks_navbar_button_link'] : '';
				$button_text    = isset( $gk_page_options['header']['geeks_navbar_button_text'] ) ? $gk_page_options['header']['geeks_navbar_button_text'] : '';
				$button_size    = isset( $gk_page_options['header']['geeks_navbar_button_size'] ) ? $gk_page_options['header']['geeks_navbar_button_size'] : '';
				$button_css     = isset( $gk_page_options['header']['geeks_navbar_button_css'] ) ? $gk_page_options['header']['geeks_navbar_button_css'] : '';
			} elseif ( $custom_header ) {
				$button_url     = geeks_get_field( 'geeks_navbar_button_link' );
				$button_text    = geeks_get_field( 'geeks_navbar_button_text' );
				$button_size    = geeks_get_field( 'geeks_navbar_button_size' );
				$button_css     = geeks_get_field( 'geeks_navbar_button_css' );
				$button_variant = geeks_get_field( 'geeks_navbar_button_variant' );

			} else {
				$button_url     = get_theme_mod( 'button_url', '#' );
				$button_text    = get_theme_mod( 'button_text', esc_html__( 'Buy Now', 'geeks' ) );
				$button_size    = get_theme_mod( 'button_size', '' );
				$button_css     = get_theme_mod( 'button_css', '' );
				$button_variant = get_theme_mod( 'button_variant' );

			}

			$btn_classes = 'navbar-btn btn';

			if ( ! empty( $button_size ) ) {
				$btn_classes .= ' ' . $button_size;
			}

			if ( ! empty( $button_css ) ) {
				$btn_classes .= ' ' . $button_css;
			}

			if ( 'outline' === $button_variant ) {
				$btn_classes .= ' btn-outline-primary';
			} else {
				$btn_classes .= ' btn-primary';
			}

			$wrap_class = 'mt-3 mt-lg-0' ;
			if ( geeks_navbar_is_user_profile_info() ) {
				$wrap_class .= ' ms-lg-3';
			} else {
				$wrap_class .= ' ms-auto';
			}
			?>

			<div class="<?php echo esc_attr( $wrap_class ); ?>">
				 <a class="<?php echo esc_attr( apply_filters( 'geeks_navbar_button_css_classes', $btn_classes ) ); ?>" href="<?php echo esc_url( apply_filters( 'geeks_navbar_button_url', $button_url ) ); ?>">
					<?php echo esc_html( apply_filters( 'geeks_navbar_button_text', $button_text ) ); ?>
				</a>
			</div>
			<?php
		endif;
	}
}


if ( ! function_exists( 'geeks_navbar_is_enable_shadow' ) ) {
	/**
	 * Enable Box Shadow
	 */
	function geeks_navbar_is_enable_shadow() {

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$enable_shadow = isset( $gk_page_options['header']['geeks_enable_navbar_shadow'] ) ? $gk_page_options['header']['geeks_enable_navbar_shadow'] : '';
		} elseif ( $custom_header ) {
			$enable_shadow = geeks_get_field( 'geeks_enable_navbar_shadow' );
		} else {
			$enable_shadow = get_theme_mod( 'enable_shadow', true );
		}

		return apply_filters( 'geeks_navbar_is_enable_shadow', filter_var( $enable_shadow, FILTER_VALIDATE_BOOLEAN ) );
	}
}

if ( ! function_exists( 'geeks_navbar_is_transparent' ) ) {
	/**
	 * Enable Box Shadow
	 */
	function geeks_navbar_is_transparent() {

		$custom_header = geeks_get_field( 'geeks_enable_custom_header' );

		$gk_page_options = array();

		if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
			$clean_meta_data  = get_post_meta( get_the_ID(), '_gk_page_options', true );
			$_gk_page_options = maybe_unserialize( $clean_meta_data );

			if ( is_array( $_gk_page_options ) ) {
				$gk_page_options = $_gk_page_options;
			}
		}

		if ( geeks_has_custom_header( $gk_page_options ) ) {
			$enable_transparent = isset( $gk_page_options['header']['geeks_enable_navbar_transparent'] ) ? $gk_page_options['header']['geeks_enable_navbar_transparent'] : '';
		} elseif ( $custom_header ) {
			$enable_transparent = geeks_get_field( 'geeks_enable_navbar_transparent' );
		} else {
			$enable_transparent = get_theme_mod( 'enable_transparent', false );
		}

		return apply_filters( 'geeks_navbar_is_transparent', filter_var( $enable_transparent, FILTER_VALIDATE_BOOLEAN ) );
	}
}

