<?php
/**
 * Template functions for Pages
 *
 */

if ( ! function_exists( 'geeks_page_header' ) ) {
	/**
	 * Display the page header
	 */
	function geeks_page_header() {
		if ( apply_filters( 'geeks_disable_page_header', false ) ) {
			return;
		}

		$version = apply_filters( 'geeks_page_header_version', 'v2' );

		if ( 'v2' === $version ) {
			geeks_page_header_v2();
		} else {
			geeks_page_header_v1();
		}
	}
}
if ( ! function_exists( 'geeks_page_header_v1' ) ) {
	/**
	 * Display the page header v1
	 *
	 * @since 1.0.0
	 */
	function geeks_page_header_v1() {
		?>
		<header class="entry-header bg-primary py-4 py-lg-6">
			<div class="container">
				<?php the_title( '<h1 class="entry-title mb-0 text-white display-4">', '</h1>' ); ?>
			</div>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'geeks_page_header_v2' ) ) {
	/**
	 * Display page header v2.
	 */
	function geeks_page_header_v2( $args = array() ) {
		$defaults = array(
			'title' => get_the_title()
		);

		if ( has_excerpt() ) {
			$defaults['lead'] = wp_strip_all_tags( get_the_excerpt() );
		}

		$args = wp_parse_args( $args, $defaults );

		geeks_get_template( 'global/page-header-v2.php', $args );
	}
}

if ( ! function_exists( 'geeks_page_content' ) ) {
	/**
	 * Display the post content
	 *
	 * @since 1.0.0
	 */
	function geeks_page_content() {
		$wrap_class = geeks_get_page_content_class();
		?>
		<div class="<?php echo esc_attr( $wrap_class ); ?>">
			<div class="container">
				<div class="row justify-content-center">
					<div class="col-lg-8 col-md-12 col-12">
						<div class="prose">
						<?php the_content(); ?>
						<?php
							wp_link_pages(
								array(
									'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'geeks' ),
									'after'  => '</div>',
								)
							);
						?>
						</div>
					</div>
				</div>
				<div class="row justify-content-center">
					<div class="col-lg-8 col-md-12 col-12"><?php geeks_display_comments(); ?></div>
				</div>
			</div>
		</div><!-- .page__content -->
		<?php
	}
}

if ( ! function_exists( 'geeks_page_content_fw' ) ) {
	/**
	 * Display the page content fullwidth
	 */
	function geeks_page_content_fw() {
		$wrap_class = geeks_get_page_content_class();
		?>
		<div class="<?php echo esc_attr( $wrap_class ); ?>">
			<div class="container">
				<div class="prose">
				<?php the_content(); ?>
				<?php
					wp_link_pages(
						array(
							'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'geeks' ),
							'after'  => '</div>',
						)
					);
				?>
				</div>
				<?php geeks_display_comments(); ?>
			</div>
		</div><!-- .page__content -->
		<?php
	}
}

/**
 * Get page content classes
 *
 * @return string
 */
function geeks_get_page_content_class() {
	$is_prose   = geeks_is_prose_enabled();
	$is_rounded = geeks_is_img_rounded_enabled();
	$classes    = 'page__content pb-10';
	
	if ( $is_prose ) {
		$classes .= ' fs-4';
	}
	
	if ( $is_rounded ) {
		$classes .= ' img-rounded-enabled';
	}

	return $classes;
}

/**
 * Return if prose is enabled or not.
 *
 * @return
 */
function geeks_is_prose_enabled() {
	return apply_filters( 'geeks_setup_prose', true );
}

/**
 * Return if rounded img is enabled.
 *
 * @return
 */
function geeks_is_img_rounded_enabled() {
	return apply_filters( 'geeks_rounded_img', true );
}

if ( ! function_exists( 'geeks_setup_prose' ) ) {
	/**
	 * Filter main content for prose.
	 *
	 * @param string $content The main content.
	 * @return string
	 */
	function geeks_setup_prose( $content ) {
		$is_prose_enabled = geeks_is_prose_enabled();
		if ( ( is_page() || is_singular( 'post' ) ) && $is_prose_enabled ) {
			
			$search = array(
				' cite="https://developer.mozilla.org/en-US/docs/Web/HTML/Element/blockquote">',
				'<blockquote>', 
				'<h1>', 
				'<h2>', 
				'<h3>', 
				'<h4>', 
				'<h5>', 
				'<h6>', 
				'<table>' 
			);
			
			$replace = array(
				'>',
				'<blockquote class="fs-3 text-dark lh-lg mb-4">', 
				'<h1 class="fw-bold mb-3">', 
				'<h2 class="fw-bold mb-3 mt-5">', 
				'<h3 class="fw-bold mb-3 mt-5">', 
				'<h4 class="fw-bold mb-3">', 
				'<h5 class="fw-bold mb-3">', 
				'<h6 class="fw-bold mb-3">', 
				'<table class="table table-bordered">' 
			);
			$content = str_replace( $search, $replace, $content );
		}
		return $content;
	}
}
