<?php
/**
 * Geeks posts template functions
 *
 * @package geeks
 */

if ( ! function_exists( 'geeks_archive_header' ) ) {
	/**
	 * Display Archive Header
	 */
	function geeks_archive_header() {
		if ( is_home() && is_front_page() ) {
			$title = esc_html__( 'Blog', 'geeks' );
			$desc  = '';
		} elseif ( is_home() ) {
			$blog_page_id = get_option( 'page_for_posts', true );
			$title        = get_the_title( $blog_page_id );
			$desc         = get_the_excerpt( $blog_page_id );
		} else {
			$title = get_the_archive_title();
			$desc  = get_the_archive_description();
		}

		$newsletter_form = apply_filters( 'geeks_newsletter_form', get_theme_mod( 'geeks_newsletter_subscription_form' ) );

		?><header class="archive-header pt-9 pb-9">
			<div class="container">
				<div class="row">
					<div class="offset-xl-2 col-xl-8 offset-lg-1 col-lg-10 col-md-12 col-12">
						<div class="text-center mb-5">
							<h1 class="page-title display-2 fw-bold"><?php echo wp_kses_post( $title ); ?></h1>
							<?php if ( ! empty( $desc ) ) : ?>
								<div class="taxonomy-description lead"><?php echo wp_kses_post( $desc ); ?></div>
							<?php endif; ?>
						</div>
						<?php geeks_search_form(); ?>
					</div>
				</div>
			</div>
		</header>
		<?php

	}
}

if ( ! function_exists( 'geeks_search_form' ) ) {
	/**
	 * Geeks Search Form
	 */
	function geeks_search_form() {
		if ( 'sfwd-courses' == get_post_type() ): 
			return;
		endif;
		ob_start();
		?>
		<form role="search" method="get" class="search-form row px-md-20" action="<?php echo esc_url( home_url( '/' ) ); ?>">
			<div class="mb-3 col ps-0  ms-2 ms-md-0">
				<input type="search" class="search-field form-control"
				placeholder="<?php echo esc_attr_x( 'Search …', 'placeholder', 'geeks' ) ?>"
				value="<?php echo get_search_query() ?>" name="s"
				title="<?php echo esc_attr_x( 'Search for:', 'label', 'geeks' ) ?>" />
				<input type="hidden" class="form-control" name="post_type" value="post">
			</div>

			<div class="mb-3 col-auto ps-0">
				<button class="btn btn-primary" type="submit"><?php echo esc_html__( 'Submit', 'geeks' );?></button>
			</div>
		</form>
		<?php
		$search_form = ob_get_clean();
		echo apply_filters( 'get_search_form', $search_form );
	}
}

if ( ! function_exists( 'geeks_loop_post_thumbnail' ) ) {
	/**
	 * Display post thumbnail in the loop.
	 *
	 * @param string $size Image size of the post thumbnail. Default is 'full'.
	 */
	function geeks_loop_post_thumbnail( $size = 'full' ) {
		if ( has_post_thumbnail() ) {
			?>
			<a href="<?php echo esc_url( get_permalink() ); ?>" class="card-img-top">
			<?php
			the_post_thumbnail( $size, array( 'class' => 'card-img-top rounded-top img-fluid' ) );
			?>
			</a>
			<?php
		}
	}
}

if ( ! function_exists( 'geeks_loop_post_category' ) ) {
	/**
	 * Display post category in the loop.
	 *
	 * @param string $cat_link_class Class for the category list.
	 */
	function geeks_loop_post_category( $cat_link_class = '' ) {
		$main_category = geeks_acf_get_main_category();
		$wrap_class    = 'mb-3 z-index-2 position-relative post__categories--loop';
		$get_cat_link_classes = trim( 'fs-5 fw-semi-bold text-reset ' . $cat_link_class );

		if ( $main_category && is_a( $main_category, 'WP_Term' ) ) {
			$text_color_class = geeks_acf_get_term_context_class( $main_category );
			$categories_list  = '<a href="' . esc_url( get_term_link( $main_category ) ) . '" class="' . esc_attr( $get_cat_link_classes ) . '" rel="category">' . $main_category->name . '</a>';
		} else {
			$find             = 'rel="category';
			$replace          = 'class="' . esc_attr( $get_cat_link_classes ) . '" rel="category';
			$categories_list  = get_the_category_list( esc_html__( ', ', 'geeks' ) );
			$categories_list  = str_replace( $find, $replace, $categories_list );
			$text_color_class = 'text-danger';

			if ( apply_filters( 'geeks_randomize_cat_color', false ) ) {
				$text_color_class = geeks_get_random_text_color_class();
			}
		}

		$wrap_class = $text_color_class . ' ' . $wrap_class;

		?>
		<div class="<?php echo esc_attr( $wrap_class ); ?>"><?php echo wp_kses_post( $categories_list );?></div>
		<?php
	}
}

if ( ! function_exists( 'geeks_loop_post_title' ) ) {
	/**
	 * Display post title in the loop.
	 */
	function geeks_loop_post_title() {
		$prepend = '';

		if ( is_sticky() ) {
			$prepend = '<span class="sticky-badge badge bg-primary fs-6 ms-2 align-middle rounded-pill">' . esc_html__( 'Featured', 'geeks' ) . '</span>';
		}

		the_title( sprintf( '<h3 class="entry-title"><a href="%s" class="text-inherit" rel="bookmark">', esc_url( get_permalink() ) ), $prepend . '</a></h3>' );
	}
}

if ( ! function_exists( 'geeks_loop_post_excerpt' ) ) {
	/**
	 * Display post excerpt in the loop.
	 */
	function geeks_loop_post_excerpt() {
		$excerpt = wp_strip_all_tags( get_the_excerpt() );
		?>
		<p><?php echo esc_html( $excerpt ); ?></p>
		<?php
	}
}

if ( ! function_exists( 'geeks_loop_post_author_info' ) ) {
	/**
	 * Display post author info in the loop.
	 */
	function geeks_loop_post_author_info( $args = array() ) {

		$defaults = array(
			'wrap_css' => ''
		);

		$args = wp_parse_args( $args, $defaults );

		$reading_time = get_post_field( 'post_content' );
		$minutes      = geeks_get_read_time( $reading_time );
		$wrap_css     = 'row align-items-center g-0 mt-4';

		if ( ! empty( $args['wrap_css'] ) ) {
			$wrap_css .= ' ' . $args['wrap_css'];
		}

		?>
		<div class="<?php echo esc_attr( $wrap_css ); ?>">
			<div class="col-auto">
			<?php
				echo get_avatar( get_the_author_meta( 'ID' ), 32, '', '', array( 'class' => 'rounded-circle avatar-sm me-2' ) );
			?>
			</div>
			<div class="col lh-1">
				<h5 class="mb-1"><?php echo esc_html( get_the_author() ); ?></h5>
				<p class="fs-6 mb-0"><?php geeks_the_post_time_string(); ?></p>
			</div>
			<?php if ( 1 <= $minutes ) : ?>
				<?php if ( 'sfwd-courses' == get_post_type() ): 
					return;
				endif;?>
				<div class="col-auto">
					<p class="font-size-xs mb-0">
						<?php
							/* translators: %s - Minutes */
							echo esc_html( sprintf( esc_html__( '%s min read', 'geeks' ), $minutes ) );
						?>
					</p>
				</div>
			<?php endif; ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_paging_nav' ) ) {
	/**
	 * Pagination for Posts
	 *
	 * @param string $ul_class Additional class to the ul element.
	 * @return void
	 */
	function geeks_paging_nav( $ul_class ) {
		global $wp_query;
		if ( $wp_query->max_num_pages <= 1 ) {
			return;
		}
		$ul_class = empty( $ul_class ) ? 'text-center mb-0 justify-content-center' : $ul_class;
		?>
		<div class="text-center mt-4">
			<?php
				geeks_bootstrap_pagination( $wp_query, true, $ul_class );
			?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_posts_results_count' ) ) {
	/**
	 * Output posts result count
	 *
	 * @param string $singular_name Singular label for the post type.
	 * @param string $plural_name   Plural label for the post type.
	 */
	function geeks_posts_results_count( $singular_name, $plural_name ) {
		?>
		<h4 id="ajax-results-count" class="<?php echo esc_attr( strtolower( $plural_name ) ); ?>__results-count mb-3 mb-lg-0">
		<?php echo esc_html( geeks_get_posts_results_count( $singular_name, $plural_name ) ); ?>
		</h4>
		<?php
	}
}

/**
 * Get the text of results count
 *
 * @param  string $singular_name Singular label for the post type.
 * @param  string $plural_name   Plural label for the post type.
 * @return null|string
 */
function geeks_get_posts_results_count( $singular_name, $plural_name ) {
	global $wp_query;

	$total         = $wp_query->found_posts;
	$total_pages   = $wp_query->max_num_pages;
	$per_page      = $wp_query->get( 'posts_per_page' );
	$current       = max( 1, $wp_query->get( 'paged', 1 ) );
	$singular_name = strtolower( $singular_name );
	$plural_name   = strtolower( $plural_name );

	if ( 0 === $total ) {
		return;
	}

	$results_count = '';

	// phpcs:disable WordPress.Security
	if ( 1 === intval( $total ) ) {
		/* translators: %s: single courses */
		$results_count = sprintf( esc_html__( 'Showing the single %s', 'geeks' ), $singular_name );
	} elseif ( $total <= $per_page || -1 === $per_page ) {
		/* translators: %d: total courses */
		$results_count = sprintf( _n( 'Showing all %1$d %2$s', 'Showing all %1$d %2$s', $total, 'geeks' ), $total, $plural_name );
	} else {
		$first = ( $per_page * $current ) - $per_page + 1;
		$last  = min( $total, $per_page * $current );
		/* translators: 1: first course 2: last course 3: total courses */
		$results_count = sprintf( _nx( 'Showing %1$d&ndash;%2$d of %3$d %4$d', 'Showing %1$d&ndash;%2$d of %3$d %5$s', $total, 'with first and last %4$s', 'geeks' ), $first, $last, $total, $singular_name, $plural_name );
	}
	// phpcs:enable WordPress.Security

	return $results_count;
}

if ( ! function_exists( 'geeks_wp_generate_tag_cloud_data' ) ) {
	/**
	 * Add tag cloud classes to generated tag cloud.
	 *
	 * @param array $tags_data An array of term data arrays for terms used to generate the tag cloud.
	 * @return array
	 */
	function geeks_wp_generate_tag_cloud_data( $tags_data ) {

		if ( $tags_data ) {
			$to = count( $tags_data );
			for ( $i = 0; $i < $to; $i++ ) {
				$tags_data[ $i ]['class'] .= ' btn btn-light btn-xs mb-2';
			}
		}

		return $tags_data;
	}
}

if ( ! function_exists( 'geeks_blog_home_categories_menu' ) ) {
	/**
	 * Display blog_categories menu.
	 */
	function geeks_blog_home_categories_menu() {
		if ( has_nav_menu( 'blog_categories' ) && is_home() && ! geeks_blog_has_sidebar() && apply_filters( 'geeks_enable_category_links', true ) ) {
			$args = array(
				'theme_location' => 'blog_categories',
				'container'      => false,
				'menu_class'     => 'nav ms-n4 text-nowrap',
				'anchor_class'   => [ 'nav-link' ],
				'anchor_active'  => true,
				'walker'         => new WP_Bootstrap_Navwalker(),
			);
			?>
		<div class="row">
			<div class="col-xl-12 col-lg-12 col-md-12 col-12">
				<div class="flush-nav"><?php wp_nav_menu( $args ); ?></div>
			</div>
		</div>
		<?php
		}
	}
}

if ( ! function_exists( 'geeks_posts_masonry_enabled' ) ) {
	/**
	 * Get the post masonry enable or disable.
	 *
	 * @return boolean
	 */
	function geeks_posts_masonry_enabled() {
		return (bool) apply_filters( 'geeks_posts_masonry_enabled', true );
	}
}

if ( ! function_exists( 'geeks_post_loop_sidebar_enabled' ) ) {
	/**
	 * Get the post loop sidebar enable or disable.
	 *
	 * @return boolean
	 */
	function geeks_post_loop_sidebar_enabled() {
		$enable_sidebar = get_theme_mod( 'geeks_enable_sidebar_widget_area', false );

		return apply_filters( 'geeks_post_loop_sidebar_enabled', filter_var( $enable_sidebar, FILTER_VALIDATE_BOOLEAN ) );
	}
}


if ( ! function_exists( 'geeks_get_blog_layout' ) ) {
	/**
	 * Get the post loop sidebar layout.
	 *
	 * @return string
	 */
	function geeks_get_blog_layout() {

		$layout = get_theme_mod( 'blog_layout', 'fullwidth' );

		return apply_filters( 'geeks_blog_layout', $layout );
	}
}

if ( ! function_exists( 'geeks_is_sticky_fullwidth' ) ) {
	/**
	 * Should sticky post be displayed in full width.
	 *
	 * @return bool
	 */
	function geeks_is_sticky_fullwidth() {
		$is_fullwidth = ( bool ) get_theme_mod( 'enable_full_width_sticky_post', false );
		return $is_fullwidth;		
	}
}

if ( ! function_exists( 'geeks_blog_has_sidebar' ) ) {
	/**
	 * Check if the blog page has sidebar.
	 *
	 * @return bool
	 */
	function geeks_blog_has_sidebar() {
		$layout              = geeks_get_blog_layout();
		$is_sidebar_enabled  = geeks_post_loop_sidebar_enabled();
		$has_sidebar         = $is_sidebar_enabled && is_active_sidebar( 'blog-sidebar' ) && 'fullwidth' !== $layout;
		return $has_sidebar;
	}
}