<?php

namespace Geeks\Tutor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Course Filter class
 */
class Course_Filter {

	/**
	 * Course category taxonomy slug.
	 *
	 * @var string
	 */
	private $category = 'course-category';

	/**
	 * Course tag taxonomy slug.
	 *
	 * @var string
	 */
	private $tag = 'course-tag';

	/**
	 * Stores the current term id during recursive operation.
	 *
	 * @var int
	 */
	private $current_term_id = null;

	/**
	 * Instantiate course filter class object
	 */
	public function __construct() {
		add_action( 'wp_ajax_tutor_course_filter_ajax', array( $this, 'load_listing' ) );
		add_action( 'wp_ajax_nopriv_tutor_course_filter_ajax', array( $this, 'load_listing' ) );
	}

	/**
	 * AJAX output after filtering
	 */
	public function load_listing() {
		// phpcs:disable WordPress.Security.NonceVerification.Missing
		tutils()->checking_nonce();

		$default_per_page = tutils()->get_option( 'courses_per_page', 12 );
		$courses_per_page = (int) sanitize_text_field( tutils()->array_get( 'course_per_page', $_POST, $default_per_page ) );
		$page             = 1;

		if ( isset( $_POST['page'] ) ) {
			$post_page = geeks_clean( wp_unslash( $_POST['page'] ) ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
			if ( is_numeric( $post_page ) && 0 < $post_page ) {
				$page = $post_page;
			}
		}

		$args = array(
			'post_status'    => 'publish',
			'post_type'      => 'courses',
			'posts_per_page' => $courses_per_page,
			'paged'          => $page,
			'tax_query'      => array( // phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_tax_query
				'relation' => 'OR',
			),
		);

		// Prepare taxonomy.
		foreach ( array( 'category', 'tag' ) as $taxonomy ) {

			$term_array = tutils()->array_get( 'tutor-course-filter-' . $taxonomy, $_POST, array() );

			if ( ! is_array( $term_array ) ) {
				$term_array = array( $term_array );
			}

			$term_array = array_filter(
				$term_array,
				function( $term_id ) {
					return is_numeric( $term_id );
				}
			);

			if ( count( $term_array ) > 0 ) {
				$tax_query = array(
					'taxonomy' => $this->$taxonomy,
					'field'    => 'term_id',
					'terms'    => $term_array,
					'operator' => 'IN',
				);
				array_push( $args['tax_query'], $tax_query );
			}
		}

		// Prepare level and price type.
		$is_membership = 'pmpro' === get_tutor_option( 'monetize_by' ) && tutils()->has_pmpro();
		$level_price   = array();
		foreach ( array( 'level', 'price' ) as $type ) {

			if ( $is_membership && 'price' === $type ) {
				continue;
			}

			$type_array = tutils()->array_get( 'tutor-course-filter-' . $type, $_POST, array() );
			$type_array = array_map( 'sanitize_text_field', ( is_array( $type_array ) ? $type_array : array( $type_array ) ) );

			if ( count( $type_array ) > 0 ) {
				$level_price[] = array(
					'key'     => 'level' === $type ? '_tutor_course_level' : '_tutor_course_price_type',
					'value'   => $type_array,
					'compare' => 'IN',
				);
			}
		}
		count( $level_price ) ? $args['meta_query'] = $level_price : 0; // phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_query

		$search_key = sanitize_text_field( tutils()->array_get( 'keyword', $_POST, null ) );

		if ( $search_key ) {
			$args['s'] = $search_key;
		}

		if ( isset( $_POST['tutor_course_filter'] ) ) {
			switch ( $_POST['tutor_course_filter'] ) {
				case 'newest_first':
					$args['orderby'] = 'ID';
					$args['order']   = 'desc';
					break;
				case 'oldest_first':
					$args['orderby'] = 'ID';
					$args['order']   = 'asc';
					break;
				case 'course_title_az':
					$args['orderby'] = 'post_title';
					$args['order']   = 'asc';
					break;
				case 'course_title_za':
					$args['orderby'] = 'post_title';
					$args['order']   = 'desc';
					break;
			}
		}

		query_posts( apply_filters( 'tutor_course_filter_args', $args ) );
		$col_per_row      = (int) sanitize_text_field( tutils()->array_get( 'column_per_row', $_POST, 3 ) );

		$GLOBALS['tutor_shortcode_arg'] = array(
			'column_per_row'  => 0 >= $col_per_row ? 3 : $col_per_row,
			'course_per_page' => $courses_per_page,
		);
		tutor_load_template( 'archive-course-init' );
		exit;
		// phpcs:enable
	}

	/**
	 * Get the current term id
	 */
	private function get_current_term_id() {

		if ( null === $this->current_term_id ) {
			$queried               = get_queried_object();
			$this->current_term_id = ( is_object( $queried ) && property_exists( $queried, 'term_id' ) ) ? $queried->term_id : false;
		}

		return $this->current_term_id;
	}

	/**
	 * Sort the terms by hierarchy
	 *
	 * @param array $terms     array of WP_Terms.
	 * @param int   $parent_id parent ID of the term.
	 */
	private function sort_terms_hierarchically( $terms, $parent_id = 0 ) {
		$term_array = array();

		foreach ( $terms as $term ) {
			if ( $term->parent === $parent_id ) {
				$term->children = $this->sort_terms_hierarchically( $terms, $term->term_id );
				$term_array[]   = $term;
			}
		}

		return $term_array;
	}

	/**
	 * Render terms by hierarchy
	 *
	 * @param array  $terms    array of WP_Terms.
	 * @param string $taxonomy course or tag.
	 */
	private function render_terms_hierarchically( $terms, $taxonomy ) {

		$term_id = $this->get_current_term_id();

		foreach ( $terms as $term ) {
			$control_id   = 'tutor-course-filter-' . $taxonomy . '-' . $term->term_id;
			$control_name = 'tutor-course-filter-' . $taxonomy;
			?>
			<div class="tutor-course-filter-nested-terms ps-4">
				<div class="form-check mb-1">
					<input type="checkbox" id="<?php echo esc_attr( $control_id ); ?>" class="form-check-input" name="<?php echo esc_attr( $control_name ); ?>" value="<?php echo esc_attr( $term->term_id ); ?>" <?php checked( $term->term_id, $term_id ); ?>>
					<label class="form-check-label" for="<?php echo esc_attr( $control_id ); ?>"><?php echo esc_html( $term->name ); ?></label>
				</div>
				<?php isset( $term->children ) ? $this->render_terms_hierarchically( $term->children, $taxonomy ) : 0; ?>
			</div>
			<?php
		}
	}

	/**
	 * Render terms
	 *
	 * @param array  $args     Array or string of arguments.
	 * @param string $taxonomy String denoting if it is a course tag or course category.
	 */
	public function render_terms( $args, $taxonomy ) {
		$terms = get_terms( $args );
		$this->render_terms_hierarchically( $this->sort_terms_hierarchically( $terms ), $taxonomy );
	}
}
